Learn R Programming

composits (version 0.1.1)

spanish_morte: A dataset containing mortality counts in Spain by state.

Description

This dataset contains mortality counts in Spain by state from the 12th of July 2018 until the 29th of July 2020.

Usage

spanish_morte

Arguments

Format

A list of two items.

1

The compositional dataset of mortality proportions by state.

2

The relevant dates.